@@ -8,9 +8,6 @@ from datetime import datetime
 from logging import getLogger, NullHandler
 logger = getLogger(__name__)
 
-def _get_all_host_bus_adapter_numbers():
-    from infi.hbaapi import get_ports_collection
-    return [port.hct[0] for port in get_ports_collection().get_ports()]
 
 class LinuxStorageModel(StorageModel):
     rescan_subprocess_timeout = 30
@@ -50,6 +47,8 @@ class LinuxStorageModel(StorageModel):
     def terminate_rescan_process(self, silent=False):
         try:
             from gipc.gipc import _GProcess as Process
+            from gevent import sleep
+            sleep(0)  # give time for gipc time to join on the defunct rescan process
         except ImportError:
             from multiprocessing import Process
         if isinstance(self.rescan_process, Process) and self.rescan_process.is_alive():
@@ -59,6 +58,7 @@ class LinuxStorageModel(StorageModel):
                 getLogger("gipc").addHandler(NullHandler())
             try:
                 self.rescan_process.terminate()
+                sleep(0)  # give time for gipc time to join on the defunct rescan process
             except Exception:
                 if not silent:
                     logger.exception("Failed to terminate rescan process")
@@ -69,6 +69,8 @@ class LinuxStorageModel(StorageModel):
         try:
             from gipc.gipc import _GProcess as Process
             from gipc.gipc import start_process
+            from gevent import sleep
+            sleep(0)  # give time for gipc time to join on the defunct rescan process
         except ImportError:
             from multiprocessing import Process
 
@@ -76,9 +78,9 @@ class LinuxStorageModel(StorageModel):
                 process = Process(*args, **kwargs)
                 process.start()
                 return process
-
         if isinstance(self.rescan_process, Process) and self.rescan_process.is_alive():
             if (datetime.now() - self.rescan_process_start_time).total_seconds() > self.rescan_subprocess_timeout:
+                logger.debug("rescan process timed out, killing it")
                 self.terminate_rescan_process()
                 self.rescan_process = None
                 self.initiate_rescan(wait_for_completion)
@@ -86,8 +88,10 @@ class LinuxStorageModel(StorageModel):
                 logger.debug("previous rescan process is still running")
                 return
         else:
+            if isinstance(self.rescan_process, Process):
+                logger.debug("previous rescan process exit code: {}".format(self.rescan_process.exitcode))
             self.rescan_process_start_time = datetime.now()
-            self.rescan_process = start_process(target=main, args=(_get_all_host_bus_adapter_numbers(),))
+            self.rescan_process = start_process(target=main)
             logger.debug("rescan process started")
             if wait_for_completion:
                 logger.debug("waiting for rescan process completion")
